"""Module docstring."""


def a_very_useful_function(one, two, three, four=3):
    """This is one of the most useful functions.

    :param str one: First argument
    :param int two: Second argument
    :param float three: Third argument
    :param four: Fourth argument
    :type four: integer or None

    """


class TheBestClass:
    """This is a class."""

    def __init__(self, value=4):
        """This is the constructor."""

    def multiplicate(self, factor):
        """Scale the thing."""



"""An insipid Sphinx theme."""
from pathlib import Path

__version__ = '0.4.2'


def setup(app):
    """Sphinx extension entry point."""
    app.require_sphinx('1.6')  # For add_html_theme()
    app.add_html_theme('insipid', Path(__file__).resolve().parent / 'insipid')
    return {
        'version': __version__,
        'parallel_read_safe': True,
    }



# Configuration file for Sphinx,
# see https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Recommended settings -----------------------------------------------------

html_theme = 'insipid'

html_permalinks_icon = '#'

# -- Recommended settings for readthedocs.org ---------------------------------

# If False, source links to Bitbucket/Github/GitLab are shown
html_copy_source = False

# -- Settings for source code -------------------------------------------------

# Language used for syntax highlighting (default: 'python')
#highlight_language = 'none'

# Style of syntax highlighting
#pygments_style = 'monokai'

# -- Language settings --------------------------------------------------------

#language = 'es'

# Date format used in footer. Use empty string for (language-specific) default.
# 'sphinx_last_updated_by_git' extension provides modification dates per page.
#html_last_updated_fmt = '%Y-%m-%d %H:%M:%S %Z'

# -- Theme configuration ------------------------------------------------------

html_theme_options = {
    #'body_centered': False,
    #'body_max_width': None,
    #'breadcrumbs': True,
    #'enable_search_shortcuts': False,
    #'globaltoc_collapse': False,
    #'globaltoc_includehidden': True,
    #'initial_sidebar_visibility_threshold': None,
    #'left_buttons': [
    #],
    #'navigation_with_keys': False,
    #'nosidebar': True,
    #'right_buttons': [
    #    'search-button.html',
    #],
    #'rightsidebar': True,
    #'show_insipid': False,
    #'sidebar_overlay_width': None,
    #'sidebar_transition': '1s ease-out',
    #'sidebarwidth': '10rem',
    #'strip_section_numbers': False,
    #'topbar_transition': '1.5s ease-out',
}

html_sidebars = {
   '**': [
       'github-badge.html',  # Custom template, see _templates/
       'home.html',
       'globaltoc.html',
       'separator.html',
       'indices.html',
   ],
   'showcase/different-sidebar': [
       'localtoc.html',
       'searchbox.html',
   ],
   'showcase/no-sidebar': [],
}

html_static_path = ['_static']
templates_path = ['_templates']

# -- Project information ------------------------------------------------------

project = 'insipid-sphinx-theme'
#html_title = 'Insipid Sphinx Theme'
html_short_title = 'insipid'
#copyright = '<insert year and copyright holder>'
#version = '3.14'
#release = '3.14.dev2'

html_logo = 'showcase/insipid.png'
html_favicon = '_static/favicon.svg'

# -- Page footer --------------------------------------------------------------

html_show_copyright = False
#html_show_sphinx = False
#html_show_sourcelink = False

# Only relevant when html_copy_source is True
#html_sourcelink_suffix = ''

# -- Miscellaneous settings ---------------------------------------------------

# Numbered figures, tables and code-blocks
numfig = True

html_secnumber_suffix = '\N{FIGURE SPACE}'

#html_compact_lists = False

#smartquotes = False

# Generate alphabetic index
#html_use_index = False

# Separate page per starting letter
#html_split_index = True

# Generate domain indices, e.g. Python module index
#html_domain_indices = False

# The default in Sphinx 4+ is 'inline'
#html_codeblock_linenos_style = 'table'

# -- Sphinx extensions --------------------------------------------------------

extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosummary',
    'sphinx.ext.intersphinx',
    'sphinx.ext.viewcode',
    'sphinx_last_updated_by_git',
]

intersphinx_mapping = {
    'sphinx': ('https://www.sphinx-doc.org/', None),
}

# -- Set path for example_module.py -------------------------------------------

# Normally, this is not necessary, because you should properly install
# your Python module before running Sphinx.

import os
import sys

sys.path.append(os.path.abspath('.'))

# -- Get version information from Git -----------------------------------------

try:
    from subprocess import check_output
    release = check_output(['git', 'describe', '--tags', '--always'])
    release = release.decode().strip()
except Exception:
    release = '<unknown>'

# -- Define custom directives/roles -------------------------------------------


def gh_template_role(rolename, rawtext, text, lineno, inliner,
                     options={}, content=()):
    from docutils import nodes, utils
    github_url = 'https://github.com/mgeier/insipid-sphinx-theme'
    blob_url = github_url + '/blob/' + release
    base_url = blob_url + '/src/insipid_sphinx_theme/insipid/%s'
    text = utils.unescape(text)
    full_url = base_url % text
    pnode = nodes.reference(internal=False, refuri=full_url)
    pnode += nodes.literal(text, text, classes=['file'])
    return [pnode], []


def setup(app):
    app.add_object_type(
        'confval', 'confval',
        objname='Sphinx configuration value',
        indextemplate='pair: %s; Sphinx configuration value')
    app.add_object_type(
        'theme-option', 'theme-option',
        objname='Theme option',
        indextemplate='pair: %s; Theme option')
    app.add_role('gh-template', gh_template_role)



from setuptools import setup

# "import" __version__
__version__ = 'unknown'
for line in open('src/insipid_sphinx_theme/__init__.py'):
    if line.startswith('__version__'):
        exec(line)
        break

setup(
    name='insipid-sphinx-theme',
    version=__version__,
    package_dir={'': 'src'},
    packages=['insipid_sphinx_theme'],
    package_data={'insipid_sphinx_theme': [
        'insipid/theme.conf',
        'insipid/*.html',
        'insipid/static/*.css',
        'insipid/static/*.css_t',
        'insipid/static/*.js',
        'insipid/static/*.js_t',
        'insipid/icons/*.svg',
    ]},
    python_requires='>=3.6',
    install_requires=[
        'sphinx>=5',
        'docutils>=0.18',
        'jinja2>=2.11',  # suport for pathlib.Path
    ],
    author='Matthias Geier',
    author_email='Matthias.Geier@gmail.com',
    description='An insipid Sphinx theme',
    long_description=open('README.rst').read(),
    license='BSD-2-Clause',
    keywords='mobile-friendly'.split(),
    url='https://insipid-sphinx-theme.readthedocs.io/',
    project_urls={
        'Documentation': 'https://insipid-sphinx-theme.readthedocs.io/',
        'Source Code': 'https://github.com/mgeier/insipid-sphinx-theme/',
        'Bug Tracker': 'https://github.com/mgeier/insipid-sphinx-theme/issues',
    },
    platforms='any',
    classifiers=[
        'Framework :: Sphinx',
        'Framework :: Sphinx :: Theme',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Documentation :: Sphinx',
    ],
    zip_safe=False,
    entry_points={
        'sphinx.html_themes': [
            'insipid = insipid_sphinx_theme',
        ]
    },
)
